==> leonardo-0.4.0-rc1.tgz: leonardo-0.4.0-rc1/lib/providers/page.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from wiki import WikiFormatter
import templates.page as template
from web_resource import PagePart, TopLevelResource, FileObjectResource



class PageProvider:
    
    
    def __init__(self, resource_manager, lfs, config):
    
        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config

        self.home_key         = config.home_key

        self.formatter        = WikiFormatter(config.home_href, lambda x: self.wiki_page(x).get_html())

       
    def get(self, resource_id, request, main_resource):

        if resource_id == "":
            resource_id = self.home_key

        page_part = self.wiki_page(resource_id)
            
        if main_resource: # if there's a parent resource, we're done
            return page_part

        if page_part.exists():
            return HTMLPage(resource_id, page_part, self.resource_manager, request, self.config)
                
        else: # new page
            if request.logged_in():
                return PageDoesNotExist(resource_id, self.resource_manager, request, self.config)
            else:
                return HTMLPage404(resource_id, self.resource_manager, request, self.config)
        

    def wiki_page(self, key):
        # note that the content type "wiki04" is used to allow concurrent use
        # of alternative wiki formats. other engines may look for other
        # content types.
        
        return WikiPagePart(key, self.lfs.get(key, "wiki04"), self.formatter)




class HTMLPage(TopLevelResource):


    def __init__(self, resource_id, page_part, resource_manager, request, config):
        TopLevelResource.__init__(self, resource_id, "text/html")

        self.resource_manager = resource_manager

        self.site_title       = config.site_title
        self.site_sub_title   = config.site_sub_title
        self.css_href         = config.css_href
        self.home_href        = config.home_href
        self.copyright_holder = config.copyright_holder
        self.home_key         = config.home_key
        self.menu_key         = config.menu_key        

        self.make_html(page_part, request)


    def exists(self):
        return True
                
        
    def get_content(self):
        return self.html    


    def is_read_only(self):
        return True


    def make_html(self, page_part, request):
        title = "%s : %s" % (self.site_title, page_part.get_title())
        content = page_part.get_html()
        time = page_part.get_lastmod()
        menu = self.resource_manager.get(self.menu_key, request, page_part).get_html()
        self.html = self.page_template(title, menu, content, time)
        

    def page_template(self, title, menu, content, lastmod):
        if lastmod:
            import time
            lastmod = time.strftime(template.time_format, time.gmtime(lastmod))
            lastmod_display = template.lastmod_display % locals()
        else:
            lastmod_display = ""
        if self.site_sub_title:
            site_sub_title = self.site_sub_title
            sub_title      = template.sub_title % locals()
        else:
            sub_title = ""
    
        site_title       = self.site_title
        home_page        = self.home_href
        copyright_holder = self.copyright_holder

        # @@@ this makes page module dependent on css module
        css_href   = self.css_href
    
        return template.page_template % locals()



class ForbiddenPage(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "403 Forbidden"
        

    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.operation_not_allowed_title % locals()
        content = template.operation_not_allowed % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        


class PageDoesNotExist(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "404 Not Found"


    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.page_does_not_exist_title % locals()
        content = template.page_does_not_exist % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        
        
    def is_read_only(self):
        return False



class HTMLPage404(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "404 Not Found"


    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.title_404 % locals()
        content = template.content_404 % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        
        
    def is_read_only(self):
        return True



class WikiPagePart(FileObjectResource, PagePart):


    def __init__(self, resource_id, file_object, formatter):
        PagePart.__init__(self, resource_id)
        FileObjectResource.__init__(self, file_object)
        self.formatter = formatter
        self.title = None


    def get_html(self):
        return self.formatter.format(self.get_content())


    def get_title(self):
        if not self.title:
            self.__update_title()
        return self.title
        
        
    def is_read_only(self):
        return False
        
        
    def __update_title(self):
        self.title = self.formatter.extract_title(self.file_object.get_content())

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/providers/page.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from wiki import WikiFormatter
#from wikiBNL import WikiFormatter

import templates.page as template
from web_resource import PagePart, TopLevelResource, FileObjectResource



class PageProvider:
    
    
    def __init__(self, resource_manager, lfs, config):
    
        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config

        self.home_key         = config.home_key

        self.formatter        = WikiFormatter(config.home_href)

       
    def get(self, resource_id, request, main_resource):

        if resource_id == "":
            resource_id = self.home_key

        page_part = self.wiki_page(resource_id, request)
            
        if main_resource: # if there's a parent resource, we're done
            return page_part

        if page_part.exists():
            return HTMLPage(resource_id, page_part, self.resource_manager, request, self.config)
                
        else: # new page
            if request.logged_in():
                return PageDoesNotExist(resource_id, self.resource_manager, request, self.config)
            else:
                return HTMLPage404(resource_id, self.resource_manager, request, self.config)
        

    def wiki_page(self, key, request):
        return WikiPagePart(key, self.resource_manager, request, self.config, self.lfs.get(key), self.formatter)



class HTMLPage(TopLevelResource):


    def __init__(self, resource_id, page_part, resource_manager, request, config):
        TopLevelResource.__init__(self, resource_id, 'text/html; charset="utf-8"')

        self.resource_manager = resource_manager

        self.site_title       = config.site_title
        self.site_sub_title   = config.site_sub_title
        self.css_href         = config.css_href
        self.home_href        = config.home_href
        self.copyright_holder = config.copyright_holder
        self.home_key         = config.home_key
        self.menu_key         = config.menu_key        

        self.make_html(page_part, request)


    def exists(self):
        return True
                
        
    def get_content(self):
        return self.html    


    def is_read_only(self):
        return True


    def make_html(self, page_part, request):
        title = page_part.get_title()
        if title:
            title = "%s : %s" % (self.site_title, title)
        else:
            title = self.site_title
        content = page_part.get_html()
        time = page_part.get_lastmod()
        menu = self.resource_manager.get(self.menu_key, request, page_part).get_html()
        self.html = self.page_template(title, menu, content, time)
        

    def page_template(self, title, menu, content, lastmod):
        if lastmod:
            import time
            lastmod = time.strftime(template.time_format, time.gmtime(lastmod))
            lastmod_display = template.lastmod_display % locals()
        else:
            lastmod_display = ""
        if self.site_sub_title:
            site_sub_title = self.site_sub_title
            sub_title      = template.sub_title % locals()
        else:
            sub_title = ""
    
        site_title       = self.site_title
        home_page        = self.home_href
        copyright_holder = self.copyright_holder

        # @@@ this makes page module dependent on css module
        css_href   = self.css_href
    
        return template.page_template % locals()



class ForbiddenPage(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "403 Forbidden"
        

    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.operation_not_allowed_title % locals()
        content = template.operation_not_allowed % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        


class PageDoesNotExist(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "404 Not Found"


    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.page_does_not_exist_title % locals()
        content = template.page_does_not_exist % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        
        
    def is_read_only(self):
        return False



class HTMLPage404(HTMLPage):


    def __init__(self, resource_id, resource_manager, request, config):
        HTMLPage.__init__(self, resource_id, None, resource_manager, request, config)
        self.status = "404 Not Found"


    def make_html(self, page_part, request):
    
        site_title = self.site_title
        title = template.title_404 % locals()
        content = template.content_404 % locals()
        time = None
        menu = self.resource_manager.get(self.menu_key, request, self).get_html()
        self.html = self.page_template(title, menu, content, time)
        
        
    def is_read_only(self):
        return True




class WikiPagePart(FileObjectResource, PagePart):

    # @@@ perhaps things like resource_manager, request, config should be moved to superclass __init__
    def __init__(self, resource_id, resource_manager, request, config, file_object, formatter):
        PagePart.__init__(self, resource_id)
        FileObjectResource.__init__(self, file_object)
        self.formatter = formatter
        self.title = None
        self.leofile = file_object
        self.resource_manager = resource_manager
        self.request = request
        self.config = config


    def get_html(self):
        return self.formatter.format(self.get_content(), self.leofile, self.resource_getter_)


    def resource_getter_(self, resource_id):
        return self.resource_manager.get(resource_id, self.request, self)
    

    def get_title(self):
        if not self.title:
            self.__update_title()
        return self.title
        
        
    def get_content_type(self):
        return "wiki04"
        
        
    def is_read_only(self):
        return False
        
        
    def __update_title(self):
        self.title = self.formatter.extract_title(self.file_object.get_content())
